package com.shzg.project.worn.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.shzg.framework.aspectj.lang.annotation.Log;
import com.shzg.framework.aspectj.lang.enums.BusinessType;
import com.shzg.project.worn.domain.MqttSensorEvent;
import com.shzg.project.worn.service.IMqttSensorEventService;
import com.shzg.framework.web.controller.BaseController;
import com.shzg.framework.web.domain.AjaxResult;
import com.shzg.common.utils.poi.ExcelUtil;
import com.shzg.framework.web.page.TableDataInfo;

/**
 * 设备事件Controller
 * 
 * @author shzg
 * @date 2026-04-01
 */
@RestController
@RequestMapping("/worn/mqttEvent")
public class MqttSensorEventController extends BaseController
{
    @Autowired
    private IMqttSensorEventService mqttSensorEventService;

    /**
     * 查询设备事件列表
     */
    @PreAuthorize("@ss.hasPermi('worn:mqttEvent:list')")
    @GetMapping("/list")
    public TableDataInfo list(MqttSensorEvent mqttSensorEvent)
    {
        startPage();
        List<MqttSensorEvent> list = mqttSensorEventService.selectMqttSensorEventList(mqttSensorEvent);
        return getDataTable(list);
    }

    /**
     * 导出设备事件列表
     */
    @PreAuthorize("@ss.hasPermi('worn:mqttEvent:export')")
    @Log(title = "设备事件", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, MqttSensorEvent mqttSensorEvent)
    {
        List<MqttSensorEvent> list = mqttSensorEventService.selectMqttSensorEventList(mqttSensorEvent);
        ExcelUtil<MqttSensorEvent> util = new ExcelUtil<MqttSensorEvent>(MqttSensorEvent.class);
        util.exportExcel(response, list, "设备事件数据");
    }

    /**
     * 获取设备事件详细信息
     */
    @PreAuthorize("@ss.hasPermi('worn:mqttEvent:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(mqttSensorEventService.selectMqttSensorEventById(id));
    }

    /**
     * 新增设备事件
     */
    @PreAuthorize("@ss.hasPermi('worn:mqttEvent:add')")
    @Log(title = "设备事件", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody MqttSensorEvent mqttSensorEvent)
    {
        return toAjax(mqttSensorEventService.insertMqttSensorEvent(mqttSensorEvent));
    }

    /**
     * 修改设备事件
     */
    @PreAuthorize("@ss.hasPermi('worn:mqttEvent:edit')")
    @Log(title = "设备事件", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody MqttSensorEvent mqttSensorEvent)
    {
        return toAjax(mqttSensorEventService.updateMqttSensorEvent(mqttSensorEvent));
    }

    /**
     * 删除设备事件
     */
    @PreAuthorize("@ss.hasPermi('worn:mqttEvent:remove')")
    @Log(title = "设备事件", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(mqttSensorEventService.deleteMqttSensorEventByIds(ids));
    }
}
